==> timetrex-2.2.17p0.tgz: timetrex/classes/modules/install/sql/mysql/1002T.sql <==
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', NULL, 1167638400, 37178, 15.5, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', NULL, 1167638400, 74357, 22, 2417);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', NULL, 1167638400, 120887, 26, 5391);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', NULL, 1167638400, 120887, 29, 9017);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NF', 1167638400, 29590, 10.57, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NF', 1167638400, 59180, 16.16, 1654);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NF', 1167638400, 59180, 18.02, 2755);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NS', 1167638400, 29590, 8.79, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NS', 1167638400, 59180, 14.95, 1823);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NS', 1167638400, 93000, 16.67, 2841);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NS', 1167638400, 93000, 17.5, 3613);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'PE', 1167638400, 30754, 9.8, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'PE', 1167638400, 61509, 13.8, 1230);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'PE', 1167638400, 61509, 16.7, 3014);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NB', 1167638400, 34186, 9.68, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NB', 1167638400, 68374, 14.82, 1757);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NB', 1167638400, 111161, 16.52, 2920);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NB', 1167638400, 111161, 17.84, 4387);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'ON', 1167638400, 35488, 6.05, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'ON', 1167638400, 70976, 9.15, 1100);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'ON', 1167638400, 70976, 11.16, 2527);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'MB', 1167638400, 30544, 10.9, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'MB', 1167638400, 65000, 13.0, 641);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'MB', 1167638400, 65000, 17.4, 3501);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'SK', 1167638400, 38405, 11.0, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'SK', 1167638400, 109720, 13.0, 768);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'SK', 1167638400, 109720, 15.0, 2963);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'BC', 1167638400, 34397, 6.05, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'BC', 1167638400, 68794, 9.15, 1066);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'BC', 1167638400, 78984, 11.70, 2821);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'BC', 1167638400, 95909, 13.70, 4400);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'BC', 1167638400, 95909, 14.70, 5359);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YU', 1167638400, 37178, 7.04, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YU', 1167638400, 74357, 9.68, 981);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YU', 1167638400, 120887, 11.44, 2290);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YU', 1167638400, 120887, 12.76, 3886);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NT', 1167638400, 35315, 5.90, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NT', 1167638400, 70631, 8.60, 954);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NT', 1167638400, 114830, 12.20, 3496);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NT', 1167638400, 114830, 14.05, 5621);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NU', 1167638400, 37178, 4.0, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NU', 1167638400, 74357, 7.0, 1115);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NU', 1167638400, 120887, 9.0, 2602);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NU', 1167638400, 120887, 11.5, 5625);

==> timetrex-5.0.3.tgz: timetrex/classes/modules/install/sql/mysql/1002T.sql <==
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', NULL, 1167638400, 37178, 15.5, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', NULL, 1167638400, 74357, 22, 2417);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', NULL, 1167638400, 120887, 26, 5391);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', NULL, 1167638400, 120887, 29, 9017);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NL', 1167638400, 29590, 10.57, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NL', 1167638400, 59180, 16.16, 1654);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NL', 1167638400, 59180, 18.02, 2755);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NS', 1167638400, 29590, 8.79, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NS', 1167638400, 59180, 14.95, 1823);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NS', 1167638400, 93000, 16.67, 2841);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NS', 1167638400, 93000, 17.5, 3613);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'PE', 1167638400, 30754, 9.8, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'PE', 1167638400, 61509, 13.8, 1230);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'PE', 1167638400, 61509, 16.7, 3014);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NB', 1167638400, 34186, 9.68, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NB', 1167638400, 68374, 14.82, 1757);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NB', 1167638400, 111161, 16.52, 2920);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NB', 1167638400, 111161, 17.84, 4387);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'ON', 1167638400, 35488, 6.05, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'ON', 1167638400, 70976, 9.15, 1100);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'ON', 1167638400, 70976, 11.16, 2527);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'MB', 1167638400, 30544, 10.9, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'MB', 1167638400, 65000, 13.0, 641);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'MB', 1167638400, 65000, 17.4, 3501);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'SK', 1167638400, 38405, 11.0, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'SK', 1167638400, 109720, 13.0, 768);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'SK', 1167638400, 109720, 15.0, 2963);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'BC', 1167638400, 34397, 6.05, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'BC', 1167638400, 68794, 9.15, 1066);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'BC', 1167638400, 78984, 11.70, 2821);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'BC', 1167638400, 95909, 13.70, 4400);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'BC', 1167638400, 95909, 14.70, 5359);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YT', 1167638400, 37178, 7.04, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YT', 1167638400, 74357, 9.68, 981);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YT', 1167638400, 120887, 11.44, 2290);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'YT', 1167638400, 120887, 12.76, 3886);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NT', 1167638400, 35315, 5.90, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NT', 1167638400, 70631, 8.60, 954);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NT', 1167638400, 114830, 12.20, 3496);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NT', 1167638400, 114830, 14.05, 5621);

INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NU', 1167638400, 37178, 4.0, 0);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NU', 1167638400, 74357, 7.0, 1115);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NU', 1167638400, 120887, 9.0, 2602);
INSERT INTO income_tax_rate VALUES (DEFAULT, 'CA', 'NU', 1167638400, 120887, 11.5, 5625);
